==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/Q4ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q4ExpressionDescription } from "./Q4ExpressionDescription";
/**
 * @hidden
 */
var Q4ExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(Q4ExpressionDescriptionMetadata, _super);
    function Q4ExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Q4ExpressionDescriptionMetadata.b = function (a) {
        if (Q4ExpressionDescriptionMetadata.a == null) {
            Q4ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            Q4ExpressionDescriptionMetadata.c(Q4ExpressionDescriptionMetadata.a);
        }
        if (a.j(Q4ExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(Q4ExpressionDescriptionMetadata.a);
    };
    Q4ExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    Q4ExpressionDescriptionMetadata.d = function (a) {
        Q4ExpressionDescriptionMetadata.b(a);
        a.aa("Q4Expression", function () { return new Q4ExpressionDescription(); });
        a.z("Q4Expression", Q4ExpressionDescriptionMetadata.a);
    };
    Q4ExpressionDescriptionMetadata.$t = markType(Q4ExpressionDescriptionMetadata, 'Q4ExpressionDescriptionMetadata');
    Q4ExpressionDescriptionMetadata.a = null;
    return Q4ExpressionDescriptionMetadata;
}(Base));
export { Q4ExpressionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/Q4ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q4ExpressionDescription } from "./Q4ExpressionDescription";
/**
 * @hidden
 */
var Q4ExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(Q4ExpressionDescriptionMetadata, _super);
    function Q4ExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Q4ExpressionDescriptionMetadata.b = function (a) {
        if (Q4ExpressionDescriptionMetadata.a == null) {
            Q4ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            Q4ExpressionDescriptionMetadata.c(Q4ExpressionDescriptionMetadata.a);
        }
        if (a.k(Q4ExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(Q4ExpressionDescriptionMetadata.a);
    };
    Q4ExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    Q4ExpressionDescriptionMetadata.d = function (a) {
        Q4ExpressionDescriptionMetadata.b(a);
        a.ac("Q4Expression", function () { return new Q4ExpressionDescription(); });
        a.ab("Q4Expression", Q4ExpressionDescriptionMetadata.a);
    };
    Q4ExpressionDescriptionMetadata.$t = markType(Q4ExpressionDescriptionMetadata, 'Q4ExpressionDescriptionMetadata');
    Q4ExpressionDescriptionMetadata.a = null;
    return Q4ExpressionDescriptionMetadata;
}(Base));
export { Q4ExpressionDescriptionMetadata };
